@@ -8,6 +8,7 @@ __copyright__ = '2014, Kovid Goyal <kovid at kovidgoyal.net>'
 
 import cPickle, os, sys
 from collections import defaultdict, OrderedDict
+from itertools import chain
 from threading import Thread
 from functools import partial
 
@@ -857,8 +858,8 @@ class WordsView(QTableView):
             for s in dictionaries.suggestions(*w):
                 cm.addAction(s, partial(self.change_to.emit, w, s))
 
-        m.addAction(_('Ignore/Unignore all selected words'), self.ignore_all)
-        a = m.addAction(_('Add/Remove all selected words'))
+        m.addAction(_('Ignore/un-ignore all selected words'), self.ignore_all)
+        a = m.addAction(_('Add/remove all selected words'))
         am = QMenu()
         a.setMenu(am)
         for dic in sorted(dictionaries.active_user_dictionaries, key=lambda x:sort_key(x.name)):
@@ -939,15 +940,11 @@ class SpellCheck(Dialog):
         self.main = m = QWidget(self)
         s.addWidget(m)
         m.l = l = QVBoxLayout(m)
-        m.h1 = h = QHBoxLayout()
-        l.addLayout(h)
         self.filter_text = t = QLineEdit(self)
         t.setPlaceholderText(_('Filter the list of words'))
         t.textChanged.connect(self.do_filter)
-        m.fc = b = QToolButton(m)
-        b.setIcon(QIcon(I('clear_left.png'))), b.setToolTip(_('Clear filter'))
-        b.clicked.connect(t.clear)
-        h.addWidget(t), h.addWidget(b)
+        t.setClearButtonEnabled(True)
+        l.addWidget(t)
 
         m.h2 = h = QHBoxLayout()
         l.addLayout(h)
@@ -1093,12 +1090,21 @@ class SpellCheck(Dialog):
             suggestions = dictionaries.suggestions(*w)
             self.suggested_list.clear()
             word_suggested = False
-            for i, s in enumerate(suggestions):
+            seen = set()
+            for i, s in enumerate(chain(suggestions, (current_word,))):
+                if s in seen:
+                    continue
+                seen.add(s)
                 item = QListWidgetItem(s, self.suggested_list)
                 if i == 0:
                     self.suggested_list.setCurrentItem(item)
                     self.suggested_word.setText(s)
                     word_suggested = True
+                if s is current_word:
+                    f = item.font()
+                    f.setItalic(True)
+                    item.setFont(f)
+                    item.setToolTip(_('The original word'))
             if not word_suggested:
                 self.suggested_word.setText(current_word)
 
